@@ -1,14 +1,14 @@
 package CatalystX::Resource;
 {
-    $CatalystX::Resource::VERSION = '0.003_003';
+  $CatalystX::Resource::VERSION = '0.005_001';
 }
 use Moose::Role;
 use CatalystX::InjectComponent;
 use namespace::autoclean;
-use 5.010;
 
 # ABSTRACT: Provide CRUD functionality to your Controllers
 
+
 after 'setup_components' => sub {
     my $class = shift;
 
@@ -38,7 +38,7 @@ CatalystX::Resource - Provide CRUD functionality to your Controllers
 
 =head1 VERSION
 
-version 0.003_003
+version 0.005_001
 
 =head1 SYNOPSIS
 
@@ -166,7 +166,7 @@ subclassed controller.
 
 Including it via C<traits =E<gt> ['MergeUploadParams']> works around this.
 
-MergeUploadParams different from the other roles. The other roles add a subroutine
+MergeUploadParams is different from the other roles. The other roles add a subroutine
 whereas MergeUploadParams uses a Moose Method Modifier.
 
 =head1 SEE ALSO
