@@ -1,6 +1,6 @@
 package CatalystX::Resource::Controller::Resource;
 {
-    $CatalystX::Resource::Controller::Resource::VERSION = '0.003_003';
+  $CatalystX::Resource::Controller::Resource::VERSION = '0.005_001';
 }
 use Moose;
 use namespace::autoclean;
@@ -14,120 +14,124 @@ use MooseX::Types::Common::String qw/ NonEmptySimpleStr /;
 
 with qw/
     CatalystX::Component::Traits
-    /;
+/;
 
 # merge traits from app config with local traits
-has '+_trait_merge' => ( default => 1 );
+has '+_trait_merge' => (default => 1);
 
 __PACKAGE__->config(
-    traits => [
-        qw/
-            List
-            Show
-            Delete
-            Form
-            Create
-            Edit
-            /
-    ],
+    traits => [qw/
+        List
+        Show
+        Delete
+        Form
+        Create
+        Edit
+    /],
     action_roles => ['MatchRequestMethod'],
 );
 
+
 has 'model' => (
     is       => 'ro',
     isa      => NonEmptySimpleStr,
     required => 1,
 );
 
+
 has 'identifier_candidates' => (
     is      => 'ro',
     isa     => 'ArrayRef',
-    default => sub { [qw/ name title /] },
+    default => sub {[ qw/ name title / ]},
 );
 
+
 has 'resultset_key' => (
     is       => 'ro',
     isa      => NonEmptySimpleStr,
     required => 1,
 );
 
+
 has 'resources_key' => (
     is       => 'ro',
     isa      => NonEmptySimpleStr,
     required => 1,
 );
 
+
 has 'resource_key' => (
     is       => 'ro',
     isa      => NonEmptySimpleStr,
     required => 1,
 );
 
+
 has 'parent_key' => (
     is        => 'ro',
     isa       => NonEmptySimpleStr,
     predicate => 'has_parent',
 );
 
+
 has 'parents_accessor' => (
     is  => 'ro',
     isa => NonEmptySimpleStr,
 );
 
+
 has 'redirect_mode' => (
     is      => 'rw',
     isa     => NonEmptySimpleStr,
     default => 'list',
 );
 
+
 has 'error_path' => (
     is      => 'ro',
     isa     => NonEmptySimpleStr,
     default => '/default',
 );
 
+
 sub _redirect {
     my ( $self, $c ) = @_;
 
     my $path;
-    my $mode     = $self->redirect_mode;
+    my $mode = $self->redirect_mode;
     my @captures = @{ $c->request->captures };
-    my $action   = $c->action->name;
+    my $action = $c->action->name;
 
     ########################
     # redirect_mode 'list' #
     ########################
-# path: /parents/1/resources/create      => redirect_path: /parents/1/resources/list
-# path: /parents/1/resources/3/edit      => redirect_path: /parents/1/resources/list
-# path: /parents/1/resources/3/delete    => redirect_path: /parents/1/resources/list
+    # path: /parents/1/resources/create      => redirect_path: /parents/1/resources/list
+    # path: /parents/1/resources/3/edit      => redirect_path: /parents/1/resources/list
+    # path: /parents/1/resources/3/delete    => redirect_path: /parents/1/resources/list
     if ( $mode eq 'list' ) {
         pop(@captures)
             unless $action eq 'create';
-        $path = $c->uri_for_action( $self->action_for('list'), \@captures );
+        $path = $c->uri_for_action($self->action_for('list'), \@captures);
     }
 
     ########################
     # redirect_mode 'show' #
     ########################
-# path: /parents/1/resources/create      => redirect_path: /parents/1/resources/<id>/show
-# path: /parents/1/resources/3/edit      => redirect_path: /parents/1/resources/3/show
-# path: /parents/1/resources/3/delete    => redirect_path: /parents/1/resources/list
+    # path: /parents/1/resources/create      => redirect_path: /parents/1/resources/<id>/show
+    # path: /parents/1/resources/3/edit      => redirect_path: /parents/1/resources/3/show
+    # path: /parents/1/resources/3/delete    => redirect_path: /parents/1/resources/list
     elsif ( $mode eq 'show' ) {
         if ( $action eq 'create' ) {
-            my $id_of_created_resource
-                = $c->stash->{ $self->resource_key }->id;
+            my $id_of_created_resource = $c->stash->{ $self->resource_key }->id;
             push @captures, $id_of_created_resource;
-            $path
-                = $c->uri_for_action( $self->action_for('show'), \@captures );
+            $path = $c->uri_for_action($self->action_for('show'), \@captures);
         }
         elsif ( $action eq 'delete' ) {
             pop(@captures);
-            $path
-                = $c->uri_for_action( $self->action_for('list'), \@captures );
+            $path = $c->uri_for_action($self->action_for('list'), \@captures);
         }
         elsif ( $action eq 'edit' ) {
-            $path
-                = $c->uri_for_action( $self->action_for('show'), \@captures );
+            $path = $c->uri_for_action($self->action_for('show'), \@captures);
         }
     }
 
@@ -142,17 +146,15 @@ sub _redirect {
     # path: /resources/3/delete              => redirect_path: /resources/list
     elsif ( $mode eq 'show_parent' ) {
         if ( $self->has_parent ) {
-            my @chain
-                = @{ $c->dispatcher->expand_action( $c->action )->{chain} };
+            my @chain = @{ $c->dispatcher->expand_action( $c->action )->{chain} };
 
             # base_with_id action of parent
             my $parent_base_with_id_action;
-            if ( $action eq 'create' ) {
+            if ($action eq 'create') {
                 $parent_base_with_id_action = $chain[-3];
-            }
-            elsif ($action eq 'edit'
-                || $action eq 'delete' )
-            {
+            } elsif ($action eq 'edit'
+                    || $action eq 'delete'
+                ) {
                 $parent_base_with_id_action = $chain[-4];
                 pop @captures;
             }
@@ -162,11 +164,10 @@ sub _redirect {
 
             # private path of show action of parent
             my $parent_show_action_private_path = "$parent_namespace/show";
-            $path = $c->uri_for_action( $parent_show_action_private_path,
-                \@captures );
+            $path = $c->uri_for_action($parent_show_action_private_path, \@captures);
         }
         else {
-            $path = $c->uri_for_action( $self->action_for('list') );
+            $path = $c->uri_for_action($self->action_for('list'));
         }
     }
 
@@ -178,16 +179,14 @@ sub _redirect {
     # path: /parents/1/resources/3/delete    => redirect_path: /parents/list
     elsif ( $mode eq 'show_parent_list' ) {
         if ( $self->has_parent ) {
-            my @chain
-                = @{ $c->dispatcher->expand_action( $c->action )->{chain} };
+            my @chain = @{ $c->dispatcher->expand_action( $c->action )->{chain} };
 
             # base action of parent
             my $parent_base_action;
-            if ( $action eq 'create' ) {
+            if ($action eq 'create') {
                 $parent_base_action = $chain[-4];
                 pop @captures;
-            }
-            elsif ( $action eq 'edit' || $action eq 'delete' ) {
+            } elsif ($action eq 'edit' || $action eq 'delete') {
                 $parent_base_action = $chain[-5];
                 pop @captures;
                 pop @captures;
@@ -198,17 +197,17 @@ sub _redirect {
 
             # private path of list action of parent
             my $parent_list_action_private_path = "$parent_namespace/list";
-            $path = $c->uri_for_action( $parent_list_action_private_path,
-                \@captures );
+            $path = $c->uri_for_action($parent_list_action_private_path, \@captures);
         }
         else {
-            $path = $c->uri_for_action( $self->action_for('list') );
+            $path = $c->uri_for_action($self->action_for('list'));
         }
     }
 
     $c->res->redirect($path);
 }
 
+
 sub _msg {
     my ( $self, $c, $action, $id ) = @_;
 
@@ -249,25 +248,28 @@ sub _msg {
     }
 }
 
+
 sub _identifier {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resource_key };
 
-    for my $identifier ( @{ $self->identifier_candidates } ) {
-        if ( $resource->can($identifier)
-            && defined $resource->$identifier )
-        {
-            return $resource->$identifier;
+    for my $identifier (@{ $self->identifier_candidates }) {
+        if (
+            $resource->can( $identifier )
+            && defined $resource->$identifier
+        ) {
+            return $resource->$identifier
         }
     }
 
-    my $identifier
-        = $resource->can('id')
+    my $identifier =
+        $resource->can('id')
         ? $self->resource_key . ' (id: ' . $resource->id . ')'
         : $self->resource_key;
-    return ucfirst($identifier);
+    return ucfirst( $identifier );
 }
 
+
 sub base : Chained('') PathPart('') CaptureArgs(0) {
     my ( $self, $c ) = @_;
 
@@ -284,6 +286,7 @@ sub base : Chained('') PathPart('') CaptureArgs(0) {
     $c->stash( $self->resultset_key => $resultset );
 }
 
+
 sub base_with_id : Chained('base') PathPart('') CaptureArgs(1) {
     my ( $self, $c, $id ) = @_;
     my $resource = $c->stash->{ $self->resultset_key }->find($id);
@@ -308,7 +311,7 @@ CatalystX::Resource::Controller::Resource - Base Controller for Resources
 
 =head1 VERSION
 
-version 0.003_003
+version 0.005_001
 
 =head1 ATTRIBUTES
 
