@@ -1,6 +1,6 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Create;
 {
-    $CatalystX::Resource::TraitFor::Controller::Resource::Create::VERSION = '0.003_003';
+  $CatalystX::Resource::TraitFor::Controller::Resource::Create::VERSION = '0.005_001';
 }
 
 use MooseX::MethodAttributes::Role;
@@ -12,7 +12,8 @@ requires qw/
     resultset_key
     resource_key
     form
-    /;
+/;
+
 
 has 'activate_fields_create' => (
     is      => 'ro',
@@ -20,8 +21,8 @@ has 'activate_fields_create' => (
     default => sub { [] },
 );
 
-sub create : Method('GET') Method('POST') Chained('base') PathPart('create')
-    Args(0) {
+
+sub create : Method('GET') Method('POST') Chained('base') PathPart('create') Args(0) {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resultset_key }->new_result( {} );
     $c->stash(
@@ -42,15 +43,15 @@ CatalystX::Resource::TraitFor::Controller::Resource::Create - a create action fo
 
 =head1 VERSION
 
-version 0.003_003
+version 0.005_001
 
 =head1 ATTRIBUTES
 
 =head2 activate_fields_create
 
-hashref of form fields to activate in the create form
-e.g. ['password', 'password_confirm']
-default = []
+(default = []).
+arrayref of form fields to activate in the create form
+(e.g. ['password', 'password_confirm'], default = [])
 Can be overriden with $c->stash->{activate_form_fields}
 
 Example: You only want admins to be able to change a field.
